.. _msaflagopen_step:

======================
MSAFlagOpen Correction
======================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.msaflagopen
